require 'spec_helper' 

describe Array do 

  describe '#suffix' do

    it "should return the input for scalar arrays" do
      ['single'].suffix.should eql 'single'
      [''].suffix.should eql ''
      [].suffix.should eql nil
    end

    it "should return the input for list input with a single repeated value" do
      (['two']    *  2).suffix.should eql 'two'
      (['three']  *  3).suffix.should eql 'three'
      (['twenty'] * 20).suffix.should eql 'twenty'
      (['two'.chars.to_a]    *  2).suffix.should eql 'two'.chars.to_a
      (['three'.chars.to_a]  *  3).suffix.should eql 'three'.chars.to_a
      (['twenty'.chars.to_a] * 20).suffix.should eql 'twenty'.chars.to_a
    end

    it "should return the largest suffix for a list of length 2" do
      ['two thousand one', 'four million'].suffix.should eql ''
      ['two thousand one.1', 'two, million.1'].suffix.should eql '.1'
      ['three thousand', 'threethousand'].suffix.should eql 'thousand'
      (['two thousand one.1', 'two, million.1'].map { |x| x.chars.to_a }).suffix.should eql '.1'.chars.to_a
      (['three thousand', 'threethousand'].map { |x| x.chars.to_a }).suffix.should eql 'thousand'.chars.to_a
    end

    it "should return the largest suffix for a list of length N" do
      (['', 'prove', 'provoke'].map { |x| x.reverse } * 2).suffix.should eql ''.reverse
      (['proud', 'prove', 'provoke'].map { |x| x.reverse } * 6).suffix.should eql 'pro'.reverse
      (['', 'prank', 'primary', 'probability'].map { |x| x.reverse } * 12).suffix.should eql ''.reverse
      (['prune', 'prank', 'primary', 'probability'].map { |x| x.reverse } * 24).suffix.should eql 'pr'.reverse
    end

  end

  describe '#prefix' do

    it "should return the input for scalar arrays" do
      ['single'].prefix.should eql 'single'
      [''].prefix.should eql ''
      [].prefix.should eql nil
    end

    it "should return the input for list input with a single repeated value" do
      (['two']    *  2).prefix.should eql 'two'
      (['three']  *  3).prefix.should eql 'three'
      (['twenty'] * 20).prefix.should eql 'twenty'
      (['two'.chars.to_a]    *  2).prefix.should eql 'two'.chars.to_a
      (['three'.chars.to_a]  *  3).prefix.should eql 'three'.chars.to_a
      (['twenty'.chars.to_a] * 20).prefix.should eql 'twenty'.chars.to_a
    end

    it "should return the largest prefix for a list of length 2" do
      ['two thousand', 'four million'].prefix.should eql ''
      ['two thousand', 'two, million'].prefix.should eql 'two'
      ['three thousand', 'threepence'].prefix.should eql 'three'
      (['three thousand', 'threepence'].map { |x| x.chars.to_a }).prefix.should eql 'three'.chars.to_a
      (['two thousand', 'two, million'].map { |x| x.chars.to_a }).prefix.should eql 'two'.chars.to_a
    end

    it "should return the largest prefix for a list of length N" do
      (['', 'prove', 'provoke'] * 2).prefix.should eql ''
      (['proud', 'prove', 'provoke'] * 6).prefix.should eql 'pro'
      (['', 'prank', 'primary', 'probability'] * 12).prefix.should eql ''
      (['prune', 'prank', 'primary', 'probability'] * 24).prefix.should eql 'pr'
    end

  end

end
