require 'spec_helper' 

describe SNMPUtils do 

  describe '#get' do

    it "should return an empty SNMP response for an invalid scalar request" do
      SNMPUtils.get({:host => 'localhost'}, 'invalid').should be_empty
      SNMPUtils.get({:host => 'localhost'}, []).should be_empty
    end

    it "should return an empty SNMP response for a mixed valid/invalid list request" do
      SNMPUtils.get({:host => 'localhost'}, ['SNMPv2-MIB::sysName.0', 'invalid']).should be_empty
      SNMPUtils.get({:host => 'localhost'}, ['invalid', 'SNMPv2-MIB::sysContact.0']).should be_empty
    end

    it "should return a hash SNMP response for a valid scalar request" do
      SNMPUtils.get({:host => 'localhost'}, 'SNMPv2-MIB::sysName.0').should_not be_empty 
      SNMPUtils.get({:host => 'localhost'}, 'SNMPv2-MIB::sysName.0').should include('SNMPv2-MIB::sysName.0')
      SNMPUtils.get({:host => 'localhost'}, 'SNMPv2-MIB::sysName.0')['SNMPv2-MIB::sysName.0'].should eql Socket.gethostname
      SNMPUtils.get({:host => 'localhost'}, '1.3.6.1.2.1.1.5.0').should_not be_empty 
      SNMPUtils.get({:host => 'localhost'}, '1.3.6.1.2.1.1.5.0').should include('1.3.6.1.2.1.1.5.0')
      SNMPUtils.get({:host => 'localhost'}, '1.3.6.1.2.1.1.5.0')['1.3.6.1.2.1.1.5.0'].should eql Socket.gethostname
    end

    it "should return a hash SNMP response for a valid list request" do
      SNMPUtils.get({:host => 'localhost'}, ['SNMPv2-MIB::sysName.0', 'SNMPv2-MIB::sysContact.0']).should include('SNMPv2-MIB::sysName.0')
      SNMPUtils.get({:host => 'localhost'}, ['SNMPv2-MIB::sysName.0', 'SNMPv2-MIB::sysContact.0']).should include('SNMPv2-MIB::sysContact.0')
    end

  end

  describe '#walk' do
    it "should return an empty SNMP response for an invalid scalar request" do
      SNMPUtils.walk({:host => 'localhost'}, 'invalid').should be_empty
      SNMPUtils.walk({:host => 'localhost'}, []).should be_empty
    end

    it "should return an empty SNMP response for a mixed valid/invalid list request" do
      SNMPUtils.walk({:host => 'localhost'}, ['SNMPv2-MIB::sysName.0', 'invalid']).should be_empty
      SNMPUtils.walk({:host => 'localhost'}, ['invalid', 'SNMPv2-MIB::sysContact.0']).should be_empty
    end

    it "should return a hash list SNMP response for a valid requests" do
      SNMPUtils.walk({:host => 'localhost'}, ['SNMPv2-MIB::sysORDescr', 'SNMPv2-MIB::sysORID']).should_not be_empty
      SNMPUtils.walk({:host => 'localhost'}, ['SNMPv2-MIB::sysORDescr', 'SNMPv2-MIB::sysORID']).each do |x|
        x.should include('SNMPv2-MIB::sysORDescr')
        x.should include('SNMPv2-MIB::sysORID')
      end
    end

  end

end
